# PaginationMeta


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**current_page** | **int** | Current page. | [optional] 
**per_page** | **int** | Number of records per page. | [optional]  if omitted the server will use the default value of 20
**record_count** | **int** | Total records in result set. | [optional] 
**total_pages** | **int** | Total pages in result set. | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


